<?php

// Set the content width based on the theme's design and stylesheet.
 
if ( ! isset( $content_width ) ) 
    $content_width = 900;

// Register widgetized area and update sidebar with default widgets

function neni_widgets_init() {
	register_sidebar( array (
		'name' => __( 'Sidebar', 'neni' ),
		'id' => 'sidebar',
        'description' => __('The widget area on the sidebar', 'neni'),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

}
add_action( 'init', 'neni_widgets_init' );

// This theme uses wp_nav_menu() in one location

function register_menus() {

	register_nav_menus( array(
		'main-menu' => __( 'Primary Navigation', 'neni' ),
	) );
 }	
	
add_action ('init', 'register_menus' );
 
// This theme supports custom background
add_custom_background();   

// Remove predefined gallery styles
add_filter('gallery_style', create_function('$a', 'return " <div class=\'gallery\'>";'));

// neni Theme Options Page

/* farbtastic */

function neni_admin_enqueue_scripts( $hook_suffix ) {
	if ( $hook_suffix != 'appearance_page_theme_options' )
		return;
	wp_enqueue_style( 'farbtastic' );
}
add_action( 'admin_enqueue_scripts', 'neni_admin_enqueue_scripts' );
 
// Default options values = default color orange
$neni_options = array(
	'custom_color' => '#EC5F00'
);

// Only create options page if user has admin rights

if ( is_admin() ) :

	function neni_register_settings() {
		register_setting( 'neni_theme_options', 'neni_options', 'neni_validate_options' ); 	// Register the settings
	}
	add_action( 'admin_init', 'neni_register_settings' );

	function neni_theme_options() {
		add_theme_page( __( 'Change Color', 'neni'), __( 'Change Color', 'neni'), 'edit_theme_options', 'theme_options', 'neni_theme_options_page'); 	// Add theme options page to the admin menu
	}
	add_action( 'admin_menu', 'neni_theme_options' );

// Function to generate options page
	function neni_theme_options_page() {
		global $neni_options, $neni_categories, $neni_layouts;

		if ( ! isset( $_REQUEST['updated'] ) )
			$_REQUEST['updated'] = false; // This checks whether the form has just been submitted. ?>
		<div class="wrap">
			<?php echo "<h2>" . __( 'neni - change color', 'neni' ) . "</h2>"; ?>
			<?php if ( false !== $_REQUEST['updated'] ) : ?>
				<div class="updated fade"><p><strong><?php _e( 'Options saved', 'neni' ); ?></strong></p></div>
			<?php endif; // If the form has just been submitted, this shows the notification ?>

			<form method="post" action="options.php">
				<?php $settings = get_option( 'neni_options', $neni_options ); ?>
				<?php settings_fields( 'neni_theme_options' ); ?>
				<?php // Show options  ?>
				<p><?php _e('Custom Color', 'neni'); ?></p>
    			<p><input id="custom_color" name="neni_options[custom_color]" type="text" value="<?php  esc_attr_e($settings['custom_color']); ?>" /></p>
				<small class="description"><?php _e('e.g. #0000FF or blue or red or green, etc. (default link color: #EC5F00)', 'neni'); ?></small>
				<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Options', 'neni'); ?>" /></p>
			</form>
			</div>
		<?php
	}
	// Validate input data
	function neni_validate_options( $input ) {
		global $neni_options, $neni_categories, $neni_layouts;
		$settings = get_option( 'neni_options', $neni_options );
		$input['custom_color'] = wp_filter_nohtml_kses( $input['custom_color'] );
		return $input;
	}

endif;  // EndIf is_admin()

// CSS for Custom Color

function insert_custom_color(){
	global $neni_options;
	$neni_settings = get_option( 'neni_options', $neni_options );
	if( $neni_settings['custom_color'] != '' ) : ?>
		<style type="text/css">
			#branding {border-top-color:  <?php echo $neni_settings['custom_color'] ; ?>!important;} 
			#colophon {border-top-color:  <?php echo $neni_settings['custom_color'] ; ?>!important;} 
			blockquote {border-left-color:  <?php echo $neni_settings['custom_color'] ; ?>!important;} 
			a, a:link, a:visited {color: <?php echo $neni_settings['custom_color'] ; ?>!important;}
			#branding #main-menu ul li a {background-color: <?php echo $neni_settings['custom_color'] ; ?>!important;}
			#branding #main-menu ul ul a:hover, #branding #main-menu ul ul ul a:hover {color: <?php echo $neni_settings['custom_color'] ; ?>!important;}
			.widget h3.widget-title, .widget_get_recent_comments h1.widget-title {color: <?php echo $neni_settings['custom_color'] ; ?>!important;}
			.widget a:hover, .widget a:active {color: <?php echo $neni_settings['custom_color'] ; ?>!important;}
			#search_submit, input#submit {color: <?php echo $neni_settings['custom_color'] ; ?>!important;} 
			#search_submit:hover, input#submit:hover {background-color: <?php echo $neni_settings['custom_color'] ; ?>!important;}
			.reply a:hover, .reply a:focus, .reply a:active {background-color: <?php echo $neni_settings['custom_color'] ; ?>!important;}
			@media screen and (max-width: 480px) {#branding #main-menu ul ul li a:hover, #branding #main-menu ul ul ul li a:hover  {color: <?php echo $neni_settings['custom_color'] ; ?>!important;} 
		</style>
	<?php endif; ?>
<?php
}

add_action('wp_head', 'insert_custom_color');




// Template for comments & pingbacks 

if ( ! function_exists( 'neni_comment' ) ) :

function neni_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php printf( __( '%s <span class="says">says:</span>', 'neni' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
		</div><!-- END .comment-author .vcard -->
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'neni' ); ?></em>
			<br />
		<?php endif; ?>
		<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				printf( __( '%1$s at %2$s', 'neni' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'neni' ), ' ' );
			?>
		</div><!-- END .comment-meta .commentmetadata -->
		<div class="comment-body"><?php comment_text(); ?></div>
		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- END .reply -->
	</div><!-- END #comment-body  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'neni' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(edit)', 'neni' ), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;

// Template for the footer. 

function footerCopyright ($showAdmin = true, $setAdminEmail = true) {
	//WP-database
	global $wpdb;
	$sqlQuery = 'SELECT MONTH(min(post_date_gmt)) AS aMonth,'.
			'YEAR(min(post_date_gmt)) AS aYear,'.
			'MONTH(max(post_date_gmt)) AS eMonth,'.	
			'YEAR(max(post_date_gmt)) AS eYear'.
			' FROM ' .$wpdb->posts.
			' WHERE post_status = "publish" ';
	$dates = $wpdb->get_results($sqlQuery);
	//Copyright
	$copyNotice = '&copy; All rights reserved, ';
	
	//Date
	if ($dates) {
		//start date
		$startDate = $dates[0]->aMonth.'/'.$dates[0]->aYear;
		//end date
		$endDate = $dates[0]->eMonth.'/'.$dates[0]->eYear;
		if ($startDate == $endDate) {
			$copyNotice .= $startDate;	
		} else {
			$copyNotice .= $startDate.' - '.$endDate;
		}
	}
	else {
		//no post -> current year
		$copyNotice .= date ('Y');
	}
	$copyNotice .= ' by ';
	//Blogname
	$copyNotice .=get_bloginfo('name');
	//Theme-Name/Url
	echo $copyNotice;
}

// This theme supports automatic feed links
add_theme_support( 'automatic-feed-links' );